@@ -1,38 +1,14 @@
 package Apache::GeoIP;
 
 use strict;
-use warnings;
-use base qw(Exporter);
-use vars qw($VERSION @EXPORT_OK);
+use vars qw($VERSION);
+require DynaLoader;
 
-$VERSION = '1.99_01';
-@EXPORT_OK = qw(find_addr);
+@Apache::GeoIP::ISA = qw(DynaLoader);
 
-sub find_addr {
-  my ($r, $xforwardedfor) = @_;
-  my $host;
-  if (defined $xforwardedfor) {
-    my $ReIpNum = qr{([01]?\d\d?|2[0-4]\d|25[0-5])};
-    my $ReIpAddr = qr{^$ReIpNum\.$ReIpNum\.$ReIpNum\.$ReIpNum$};
-    $host =  $r->header_in('X-Forwarded-For') || 
-      $r->connection->remote_ip;
-    if ($host =~ /,/) {
-      my @a = split /\s*,\s*/, $host;
-      for my $i (0 .. $#a) {
-          if ($a[$i] =~ /$ReIpAddr/ and $a[$i] ne '127.0.0.1') {
-              $host = $a[$i];
-              last;
-          }
-      }
-      $host = '127.0.0.1' if $host =~ /,/;
-    }
-  }
-  else {
-    $host = $r->connection->remote_ip;
-  }
-  return $host;
-}
+$VERSION = '1.12';
 
+__PACKAGE__->bootstrap($VERSION);
 
 1;
 
@@ -52,9 +28,6 @@ This free database is similar to the database contained in IP::Country, as
 well as many paid databases. It uses ARIN, RIPE, APNIC, and LACNIC whois to 
 obtain the IP->Country mappings.
 
-For Win32 users, the F<GeoIP.dat> database file is expected
-to reside in the F</Program Files/GeoIP/> directory.
-
 If you require greater accuracy, MaxMind offers a Premium database on a paid 
 subscription basis. 
 
